==> piwigo-2.5.1.zip: piwigo/language/nn_NO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Database name'] = 'Databasenamn';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Du kan endre konfigurasjonen sjølv og ta omstart på Piwigo etterpå.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Du bør sjekke med dei som leverar nett-tenaren om korleis du kan byte til PHP5.';
$lang['also given by your host provider'] = 'er og levera av den som leverar nett-tenaren';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'namna på databasetabellane vil verta prefiksa med dette (gjev deg mogleghet til å handtere databasetabellane betre)';
$lang['enter a login for webmaster'] = 'skriv inn brukarnamn for webmaster';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-postadressa må vera på forma xxx@yyy.eee (døme: jack@example.com)';
$lang['please enter your password again'] = 'skriv inn passord ei gong til';
$lang['user login given by your host provider'] = 'brukarnamn du har fått av den som har nett-tenaren';
$lang['user password given by your host provider'] = 'passord du har fått av den som har nett-tenaren';
$lang['verification'] = 'sjekk';
$lang['webmaster login can\'t contain characters \' or "'] = 'brukarnamn for webmaster kan ikkje innehalde tegna \' eller "';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ikkje vent med å sjå på foruma våre for hjelp: %s';
$lang['PHP 5 is required'] = 'PHP5 er påkrevd';
$lang['Password'] = 'Passord';
$lang['Password ']['confirm'] = 'Passord [stadfest]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve å byte din konfigurasjon til PHP5 ved å lage eller endre fila .htaccess.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo greidde ikkje å konfigurere PHP5.';
$lang['Sorry!'] = 'Orsak!';
$lang['Start Install'] = 'Start installasjon';
$lang['Try to configure PHP 5'] = 'Prøv å konfigurere PHP5';
$lang['User'] = 'Brukar';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Dei som vitjar nettsida kan bruke denne e-postadressa for å kontakte administrator for nettsida';
$lang['Webmaster login'] = 'Login for webmaster';
$lang['Webmaster mail address'] = 'E-postadresse for webmaster';
$lang['Webmaster password'] = 'Passord for webmaster';
$lang['Welcome to my photo gallery'] = 'Velkomen til mitt biletgalleri';
$lang['Welcome to your new installation of Piwigo!'] = 'Velkomen til din nye installasjon av Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan laste ned konfigurasjonsfila og laste den opp til "local/config" katalogen i din installasjon.';
$lang['Admin configuration'] = 'Administratorkonfigurasjone';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Ein alternativ løysing er å kopiere teksten i boksen over og lime den inn i fila "local/config/database.inc.php" (Åtvaring: "database.inc.php" kan bare innehalde det som er i tekstfeltet, ikkje lineskift eller mellomrom)';
$lang['Basic configuration'] = 'Grunnleggande konfigurasjon';
$lang['Can\'t connect to server'] = 'Kan ikkje kople til tenar';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulere, installasjon av Piwigo er ferdig';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Kopling til tenar er vellukka, men tilkopling til databasen var ikkje mogleg.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Oppretting av konfigurasjonsfila "local/config/database.inc.php" feila.';
$lang['Database configuration'] = 'Databasekonfigurasjon';
$lang['Database table prefix'] = 'Prefiks for databasetabellar';
$lang['Default gallery language'] = 'Standard språk for galleriet';
$lang['Download the config file'] = 'Last ned konfigurasjonsfil';
$lang['Hope to see you back soon.'] = 'Håpar å sjå deg att snart.';
$lang['Host'] = 'Tenar';
$lang['Installation'] = 'Installasjon';
$lang['It appears your webhost is currently running PHP %s.'] = 'Det verkar som nettenaren køyrer PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Den vil bli vist til dei som vitjar galleriet. Den er naudsynt for administrasjon av nettsida';
$lang['Just another Piwigo gallery'] = 'Enda eit Piwigo galleri';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hald dette hemmeleg, det gjev deg tilgang til administrasjonspanelet';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Treng du hjelp? Still spørsmålet ditt på <a href="%s"> Piwigo sitt forum</a>.';
?>

==> piwigo-2.7.4.zip: piwigo/language/nn_NO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Database name'] = 'Databasenamn';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Du kan endre konfigurasjonen sjølv og ta omstart på Piwigo etterpå.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Du bør sjekke med dei som leverar nett-tenaren om korleis du kan byte til PHP5.';
$lang['also given by your host provider'] = 'er og levera av den som leverar nett-tenaren';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'namna på databasetabellane vil verta prefiksa med dette (gjev deg mogleghet til å handtere databasetabellane betre)';
$lang['enter a login for webmaster'] = 'skriv inn brukarnamn for webmaster';
$lang['please enter your password again'] = 'skriv inn passord ei gong til';
$lang['user login given by your host provider'] = 'brukarnamn du har fått av den som har nett-tenaren';
$lang['user password given by your host provider'] = 'passord du har fått av den som har nett-tenaren';
$lang['verification'] = 'sjekk';
$lang['webmaster login can\'t contain characters \' or "'] = 'brukarnamn for webmaster kan ikkje innehalde tegna \' eller "';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ikkje vent med å sjå på foruma våre for hjelp: %s';
$lang['PHP 5 is required'] = 'PHP5 er påkrevd';
$lang['Password ']['confirm'] = 'Passord [stadfest]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve å byte din konfigurasjon til PHP5 ved å lage eller endre fila .htaccess.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo greidde ikkje å konfigurere PHP5.';
$lang['Sorry!'] = 'Orsak!';
$lang['Start Install'] = 'Start installasjon';
$lang['Try to configure PHP 5'] = 'Prøv å konfigurere PHP5';
$lang['User'] = 'Brukar';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Dei som vitjar nettsida kan bruke denne e-postadressa for å kontakte administrator for nettsida';
$lang['Welcome to my photo gallery'] = 'Velkomen til mitt biletgalleri';
$lang['Welcome to your new installation of Piwigo!'] = 'Velkomen til din nye installasjon av Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan laste ned konfigurasjonsfila og laste den opp til "local/config" katalogen i din installasjon.';
$lang['Admin configuration'] = 'Administratorkonfigurasjone';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Ein alternativ løysing er å kopiere teksten i boksen over og lime den inn i fila "local/config/database.inc.php" (Åtvaring: "database.inc.php" kan bare innehalde det som er i tekstfeltet, ikkje lineskift eller mellomrom)';
$lang['Basic configuration'] = 'Grunnleggande konfigurasjon';
$lang['Can\'t connect to server'] = 'Kan ikkje kople til tenar';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulere, installasjon av Piwigo er ferdig';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Kopling til tenar er vellukka, men tilkopling til databasen var ikkje mogleg.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Oppretting av konfigurasjonsfila "local/config/database.inc.php" feila.';
$lang['Database configuration'] = 'Databasekonfigurasjon';
$lang['Database table prefix'] = 'Prefiks for databasetabellar';
$lang['Default gallery language'] = 'Standard språk for galleriet';
$lang['Download the config file'] = 'Last ned konfigurasjonsfil';
$lang['Hope to see you back soon.'] = 'Håpar å sjå deg att snart.';
$lang['Host'] = 'Tenar';
$lang['Installation'] = 'Installasjon';
$lang['It appears your webhost is currently running PHP %s.'] = 'Det verkar som nettenaren køyrer PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Den vil bli vist til dei som vitjar galleriet. Den er naudsynt for administrasjon av nettsida';
$lang['Just another Piwigo gallery'] = 'Enda eit Piwigo galleri';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hald dette hemmeleg, det gjev deg tilgang til administrasjonspanelet';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Treng du hjelp? Still spørsmålet ditt på <a href="%s"> Piwigo sitt forum</a>.';
$lang['localhost or other, supplied by your host provider'] = 'localhost eller servernamn gjeve av administrator for server';
?>
